.. _fluent_pages.models.navigation:

fluent_pages.models.navigation
==============================

.. automodule:: fluent_pages.models.navigation

The ``NavigationNode`` class
----------------------------

.. autoclass:: fluent_pages.models.navigation.NavigationNode
   :members:

The ``PageNavigationNode`` class
--------------------------------

.. autoclass:: fluent_pages.models.navigation.PageNavigationNode
   :members:

